<?php

namespace Drupal\monarch_bootstrap\Plugin\Alter;

use Drupal\Core\Plugin\PluginBase;
use Drupal\Core\Theme\ThemeManagerInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Base class for alter plugins.
 */
abstract class AlterBase extends PluginBase 
  implements AlterInterface, ContainerFactoryPluginInterface {

  /**
   * The alter hook invoked.
   *
   * @var string
   */
  protected $hook;

  /**
   * The theme manager service.
   * 
   * @var \Drupal\Core\Theme\ThemeManagerInterface
   */
  protected $themeManager;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('theme.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function __construct(
    array $configuration, $plugin_id, $plugin_definition,
    ThemeManagerInterface $theme_manager) {

    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->hook = $configuration['hook'] ?? NULL;
    $this->themeManager = $theme_manager;
  }

  /**
   * Get the active theme object.
   * 
   * @return \Drupal\Core\Theme\ActiveTheme
   */
  public function getActiveTheme() {
    return $this->themeManager->getActiveTheme();
  }

}
